@@ -1,8 +1,10 @@
+import re
+
 import genshi
+from sqlalchemy import or_, func, desc
 
 import ckan.misc
 from ckan.lib.base import *
-from sqlalchemy import or_, func, desc
 
 def login_form():
     return render('user/login_form.html').replace('FORM_ACTION', '%s')
@@ -48,7 +50,7 @@ class UserController(BaseController):
         if id:
             user = model.User.get(id)
         else:
-            user = model.User.by_name(c.user)
+            user = c.userobj
         if not user:
             h.redirect_to(controller='user', action='login', id=None)
         c.read_user = user.display_name
@@ -65,7 +67,8 @@ class UserController(BaseController):
     def me(self):
         if not c.user:
             h.redirect_to(controller='user', action='login', id=None)
-        h.redirect_to(controller='user', action='read', id=c.user)
+        user_ref = c.userobj.get_reference_preferred_for_uri()
+        h.redirect_to(controller='user', action='read', id=user_ref)
 
     def register(self):
         if not self.authorizer.am_authorized(c, model.Action.USER_CREATE, model.System):
@@ -99,8 +102,8 @@ class UserController(BaseController):
             response.set_cookie("ckan_user", userobj.name)
             response.set_cookie("ckan_display_name", userobj.display_name)
             response.set_cookie("ckan_apikey", userobj.apikey)
-            h.flash_notice(_("Welcome back, %s") % userobj.display_name)
-            h.redirect_to(controller='home', action='index', id=None)
+            h.flash_success(_("Welcome back, %s") % userobj.display_name)
+            h.redirect_to(controller='user', action='me', id=None)
         else:
             h.flash_error('Login failed. Bad username or password.')
             h.redirect_to(controller='user', action='login')
