@@ -20,7 +20,7 @@ class CreateTestData(cli.CkanCommand):
     pkg_names = []
     tag_names = []
     group_names = set()
-    user_names = []
+    user_refs = []
     
     pkg_core_fields = ['name', 'title', 'version', 'url', 'notes',
                        'author', 'author_email',
@@ -28,8 +28,10 @@ class CreateTestData(cli.CkanCommand):
                        ]
 
     def command(self):
+        from ckan import plugins
         self._load_config()
         self._setup_app()
+        plugins.load('synchronous_search') # so packages get indexed
         if self.args:
             cmd = self.args[0]
         else:
@@ -39,7 +41,7 @@ class CreateTestData(cli.CkanCommand):
         if cmd == 'basic':
             self.create_basic_test_data()
         elif cmd == 'user':
-            self.create_user()
+            self.create_test_user()
             print 'Created user %r with password %r and apikey %r' % ('tester',
                     'tester', 'tester')
         elif cmd == 'search':
@@ -73,7 +75,7 @@ class CreateTestData(cli.CkanCommand):
                               extra_user_names=extra_users)
 
     @classmethod
-    def create_user(cls):
+    def create_test_user(cls):
         import ckan.model as model
         tester = model.User.by_name(u'tester')
         if tester is None:
@@ -82,7 +84,7 @@ class CreateTestData(cli.CkanCommand):
             model.Session.add(tester)
             model.Session.commit()
         model.Session.remove()
-        cls.user_names = [u'tester']
+        cls.user_refs.append(u'tester')
 
     @classmethod
     def create_arbitrary(cls, package_dicts, relationships=[],
@@ -206,7 +208,7 @@ class CreateTestData(cli.CkanCommand):
             if not model.User.by_name(unicode(user_name)):
                 user = model.User(name=unicode(user_name))
                 model.Session.add(user)
-                cls.user_names.append(user_name)
+                cls.user_refs.append(user_name)
                 needs_commit = True
 
         if needs_commit:
@@ -375,12 +377,12 @@ left arrow <
         # authz
         model.Session.add_all([
             model.User(name=u'tester', apikey=u'tester', password=u'tester'),
-            model.User(name=u'joeadmin'),
-            model.User(name=u'annafan', about=u'I love reading Annakarenina'),
-            model.User(name=u'russianfan'),
-            model.User(name=u'testsysadmin'),
+            model.User(name=u'joeadmin', password=u'joeadmin'),
+            model.User(name=u'annafan', about=u'I love reading Annakarenina', password=u'annafan'),
+            model.User(name=u'russianfan', password=u'russianfan'),
+            model.User(name=u'testsysadmin', password=u'testsysadmin'),
             ])
-        cls.user_names.extend([u'tester', u'joeadmin', u'annafan', u'russianfan', u'testsysadmin'])
+        cls.user_refs.extend([u'tester', u'joeadmin', u'annafan', u'russianfan', u'testsysadmin'])
         model.repo.commit_and_remove()
 
         visitor = model.User.by_name(model.PSEUDO_USER__VISITOR)
@@ -405,6 +407,48 @@ left arrow <
             from ckan.model.changeset import ChangesetRegister
             changeset_ids = ChangesetRegister().commit()
 
+        # Create a couple of authorization groups
+        for ag_name in [u'anauthzgroup', u'anotherauthzgroup']:
+            ag=model.AuthorizationGroup.by_name(ag_name) 
+            if not ag: #may already exist, if not create
+                ag=model.AuthorizationGroup(name=ag_name)
+                model.Session.add(ag)
+
+        model.repo.commit_and_remove()
+
+        # and give them a range of roles on various things
+        ag = model.AuthorizationGroup.by_name(u'anauthzgroup')
+        aag = model.AuthorizationGroup.by_name(u'anotherauthzgroup')
+        pkg = model.Package.by_name(u'warandpeace')
+        g = model.Group.by_name('david')
+
+        model.add_authorization_group_to_role(ag, u'editor', model.System())
+        model.add_authorization_group_to_role(ag, u'reader', pkg)
+        model.add_authorization_group_to_role(ag, u'admin', aag)
+        model.add_authorization_group_to_role(aag, u'editor', ag)
+        model.add_authorization_group_to_role(ag, u'editor', g)
+
+        model.repo.commit_and_remove()
+
+
+
+
+
+    @classmethod
+    def create_user(cls, name='', **kwargs):
+        import ckan.model as model
+        # User objects are not revisioned
+        user_ref = name or kwargs['openid']
+        assert user_ref
+        for k, v in kwargs.items():
+            if v:
+                # avoid unicode warnings
+                kwargs[k] = unicode(v)
+        user = model.User(name=unicode(name), **kwargs)
+        model.Session.add(user)
+        model.Session.commit()
+        cls.user_refs.append(user_ref)
+
     @classmethod
     def flag_for_deletion(cls, pkg_names=[], tag_names=[], group_names=[],
                           user_names=[]):
@@ -416,7 +460,7 @@ left arrow <
         cls.pkg_names.extend(pkg_names)
         cls.tag_names.extend(tag_names)
         cls.group_names = cls.group_names.union(set(group_names))
-        cls.user_names.extend(user_names)
+        cls.user_refs.extend(user_names)
 
     @classmethod
     def delete(cls):
@@ -449,8 +493,8 @@ left arrow <
                 grp.purge()
             model.Session.commit()
             model.Session.delete(rev)
-        for user_name in cls.user_names:
-            user = model.User.by_name(unicode(user_name))
+        for user_name in cls.user_refs:
+            user = model.User.get(unicode(user_name))
             if user:
                 user.purge()
         model.Session.commit()
@@ -462,11 +506,11 @@ left arrow <
         cls.pkg_names = []
         cls.group_names = set()
         cls.tag_names = []
-        cls.user_names = []
+        cls.user_refs = []
 
     @classmethod
     def get_all_data(cls):
-        return cls.pkg_names + list(cls.group_names) + cls.tag_names + cls.user_names
+        return cls.pkg_names + list(cls.group_names) + cls.tag_names + cls.user_refs
 
 
 search_items = [{'name':'gils',
