@@ -1,5 +1,6 @@
 import datetime
-from time import mktime, gmtime
+from time import gmtime
+from calendar import timegm
 
 from sqlalchemy.sql import select, and_, union, expression
 from sqlalchemy.orm import eagerload_all
@@ -11,6 +12,7 @@ from types import make_uuid
 from core import *
 from license import License, LicenseRegister
 from domain_object import DomainObject
+import ckan.misc
 
 __all__ = ['Package', 'package_table', 'package_revision_table',
            'PACKAGE_NAME_MAX_LENGTH', 'PACKAGE_VERSION_MAX_LENGTH']
@@ -76,44 +78,70 @@ class Package(vdm.sqlalchemy.RevisionedObjectMixin,
 
         return self.resource_groups_all[0].resources
     
-
     def update_resources(self, res_dicts, autoflush=True):
         '''Change this package\'s resources.
         @param res_dicts - ordered list of dicts, each detailing a resource
         The resource dictionaries contain 'url', 'format' etc. Optionally they
         can also provide the 'id' of the Resource, to help matching
         res_dicts to existing Resources. Otherwise, it searches
-        for an exactly matchinrce.
+        for an otherwise exactly matching Resource.
         The caller is responsible for creating a revision and committing.'''
-        import resource
+        from ckan import model
         assert isinstance(res_dicts, (list, tuple))
         # Map the incoming res_dicts (by index) to existing resources
         index_to_res = {}
         # Match up the res_dicts by id
+        def get_resource_identity(resource_obj_or_dict):
+            if isinstance(resource_obj_or_dict, dict):
+                # Convert dict into a Resource object, since that ensures
+                # all columns exist when you redictize it. This object is
+                # garbage collected as it isn't added to the Session.
+                res_keys = set(resource_obj_or_dict.keys()) - \
+                           set(('id', 'position'))
+                res_dict = dict([(res_key, resource_obj_or_dict[res_key]) \
+                                 for res_key in res_keys])
+                resource = model.Resource(**res_dict)
+            else:
+                resource = resource_obj_or_dict
+            res_dict = resource.as_dict(core_columns_only=True)
+            return res_dict
+        existing_res_identites = [get_resource_identity(res) \
+                                  for res in self.resources]
         for i, res_dict in enumerate(res_dicts):
             assert isinstance(res_dict, dict)
             id = res_dict.get('id')
             if id:
-                res = Session.query(resource.Resource).autoflush(autoflush).get(id)
+                res = Session.query(model.Resource).autoflush(autoflush).get(id)
                 if res:
                     index_to_res[i] = res
+            else:
+                res_identity = get_resource_identity(res_dict)
+                try:
+                    matching_res_index = existing_res_identites.index(res_identity)
+                except ValueError:
+                    continue
+                index_to_res[i] = self.resources[matching_res_index]
+                
         # Edit resources and create the new ones
         new_res_list = []
 
         for i, res_dict in enumerate(res_dicts):
             if i in index_to_res:
                 res = index_to_res[i]
-                for col, value in res_dict.items():
-                    setattr(res, col, value)
+                for col in set(res_dict.keys()) - set(('id', 'position')):
+                    setattr(res, col, res_dict[col])
             else:
                 # ignore particular keys that disrupt creation of new resource
-                for key in ('id', 'position'):
-                    if res_dict.has_key(key):
-                        del res_dict[key]
-                res = resource.Resource(**res_dict)
+                for key in set(res_dict.keys()) & set(('id', 'position')):
+                    del res_dict[key]
+                res = model.Resource(**res_dict)
+                model.Session.add(res)
             new_res_list.append(res)
         self.resource_groups[0].resources = new_res_list
 
+    def related_packages(self):
+        return [self]
+
     def add_resource(self, url, format=u'', description=u'', hash=u'', **kw):
         import resource
         self.resources.append(resource.Resource(
@@ -177,6 +205,7 @@ class Package(vdm.sqlalchemy.RevisionedObjectMixin,
             if self.metadata_modified else None
         _dict['metadata_created'] = self.metadata_created.isoformat() \
             if self.metadata_created else None
+        _dict['notes_rendered'] = ckan.misc.MarkdownFormat().to_html(self.notes)
         return _dict
 
     def add_relationship(self, type_, related_package, comment=u''):
@@ -280,8 +309,9 @@ class Package(vdm.sqlalchemy.RevisionedObjectMixin,
                     continue
                 # and check children
                 child_pkg = parent_rel_as_object.subject
-                if child_pkg != self and \
-                       parent_rel_as_object.type == rel_as_subject.type:
+                if (child_pkg != self and 
+                    parent_rel_as_object.type == rel_as_subject.type and
+                    child_pkg.state == State.ACTIVE):
                     type_printable = PackageRelationship.inferred_types_printable['sibling']
                     rel_list.append((child_pkg, type_printable, None))
         return sorted(list(set(rel_list)))
@@ -456,13 +486,14 @@ class Package(vdm.sqlalchemy.RevisionedObjectMixin,
             usecs = float(result[0].microsecond) / 1e6
         else:
             timestamp, usecs = gmtime(), 0
-        return mktime(timestamp) + usecs
+        # use timegm instead of mktime, because we don't want it localised
+        return timegm(timestamp) + usecs
 
     @property
     def metadata_modified(self):
         import ckan.model as model
         epochtime = self.last_modified(model.package_table.c.id==self.id)
-        return datetime.datetime.fromtimestamp(epochtime)
+        return datetime.datetime.utcfromtimestamp(epochtime)
     
     @property
     def metadata_created(self):
