@@ -4,7 +4,7 @@
         var basic = $(this);
         var further = basic.next('.further');
         if (further.length) {
-            var more = $('<span class="more">&nbsp;<span class="as_hyperlink">More &raquo;</span></span>');
+            var more = $('<span class="more">&nbsp;<span class="as_hyperlink">' + MSG_MORE_HELP + '</span></span>');
             basic.append(more);
             further.hide();
             more.click(function(){
