@@ -44,7 +44,6 @@ class TestTagController(TestController):
     def test_list_short(self):
         offset = url_for(controller='tag', action='index')
         res = self.app.get(offset)
-        print str(res)
         tagname = 'tolstoy'
         assert tagname in res
         #assert '(2 packages)' in res
@@ -52,14 +51,12 @@ class TestTagController(TestController):
         assert tagname in res
         offset = url_for(controller='tag', action='index')
         res = self.app.get(offset)
-        print str(res)
         assert tagname in res
         #assert '(2 packages)' in res
         tag_count = model.Session.query(model.Tag).count()
         assert 'There are <strong>%s</strong> results for tags.' % tag_count in res
         offset = url_for(controller='tag', action='index')
         res = self.app.get(offset)
-        print str(res)
         assert tagname in res
         tag_count = model.Session.query(model.Tag).count()
         assert 'There are <strong>%s</strong> results for tags.' % tag_count in res
@@ -71,23 +68,23 @@ class TestTagController(TestController):
         res = self.app.get(offset)
         search_term = 's'
         fv = res.forms['tag-search']
-        print fv.fields
         fv['q'] =  str(search_term)
         res = fv.submit()
-        print res
         assert 'There are <strong>2</strong> results' in res, res
         assert 'russian' in res, res
         assert 'tolstoy' in res, res
 
     def test_autocomplete(self):
-        offset = url_for(controller='tag', action='autocomplete')
+        controller = 'api'
+        action = 'tag_autocomplete'
+        offset = url_for(controller=controller, action=action)
         res = self.app.get(offset)
         assert '[]' in res
-        offset = url_for(controller='tag', action='autocomplete', incomplete='russian')
+        offset = url_for(controller=controller, action=action, incomplete='russian')
         res = self.app.get(offset)
         assert 'russian' in res
         assert 'tolstoy' not in res
-        offset = url_for(controller='tag', action='autocomplete', incomplete='tolstoy')
+        offset = url_for(controller=controller, action=action, incomplete='tolstoy')
         res = self.app.get(offset)
         assert 'russian' not in res
         assert 'tolstoy' in res
