@@ -11,7 +11,11 @@ class HtmlCheckMethods(object):
     def named_div(self, div_name, html):
         'strips html to just the <div id="DIV_NAME"> section'
         the_html = html.body.decode('utf8')
-        div_html = the_html[the_html.find(u'<div id="%s"' % div_name):the_html.find(u'<!-- /%s -->' % div_name)]
+        start_div = the_html.find(u'<div id="%s"' % div_name)
+        end_div = the_html.find(u'<!-- #%s -->' % div_name)
+        if end_div == -1:
+            end_div = the_html.find(u'<!-- /%s -->' % div_name)
+        div_html = the_html[start_div:end_div]
         assert div_html
         return div_html
 
